Struct leveldb_rs::DBWriteOptions
[−]
[src]
pub struct DBWriteOptions { /* fields omitted */ }This structure represents options that can be used when writing to a LevelDB instance.
Methods
impl DBWriteOptions[src]
fn new() -> Option<DBWriteOptions>
Create and return a new DBWriteOptions instance. Returns None if the
underlying library call returns a null pointer.
fn set_sync(&mut self, val: bool) -> &mut DBWriteOptions
Set whether the write will be flushed to disk before the write is
considered "complete". Essentially, if a write is performed without
this value set, it has the same semantics as the write() syscall. If
sync is set, the semantics are the same as a write() followed by a
fsync() call.
The default value is false.